/**
 * @file resolve-url.js
 */
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _slicedToArray = (function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i['return']) _i['return'](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError('Invalid attempt to destructure non-iterable instance'); } }; })();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _globalDocument = require('global/document');

var _globalDocument2 = _interopRequireDefault(_globalDocument);

/**
 * Creates an iframe to contain our base and anchor elements for url resolving function
 */
var createResolverElements = function createResolverElements() {
  var iframe = _globalDocument2['default'].createElement('iframe');

  iframe.style.display = 'none';
  iframe.src = 'about:blank';
  _globalDocument2['default'].body.appendChild(iframe);

  var iframeDoc = iframe.contentWindow.document;

  iframeDoc.open();
  iframeDoc.write('<html><head><base></base></head><body><a></a></body></html>');
  iframeDoc.close();

  var base = iframeDoc.querySelector('base');
  var anchor = iframeDoc.querySelector('a');

  _globalDocument2['default'].body.removeChild(iframe);

  return [base, anchor];
};

/**
 * Build a new URI resolver by adding an iframe for resolving and returning a resolving function
 * that can be disposed
 */
var resolveUrlFactory = function resolveUrlFactory() {
  var _createResolverElements = createResolverElements();

  var _createResolverElements2 = _slicedToArray(_createResolverElements, 2);

  var base = _createResolverElements2[0];
  var anchor = _createResolverElements2[1];

  /**
   * Constructs a new URI by interpreting a path relative to another
   * URI.
   *
   * @see http://stackoverflow.com/questions/470832/getting-an-absolute-url-from-a-relative-one-ie6-issue
   * @param {String} basePath a relative or absolute URI
   * @param {String} path a path part to combine with the base
   * @return {String} a URI that is equivalent to composing `base`
   * with `path`
   */
  var resolveUrl = function resolveUrl(basePath, path) {
    if (basePath !== base.href) {
      base.href = basePath;
    }
    anchor.href = path;
    return anchor.href;
  };

  return resolveUrl;
};

exports['default'] = resolveUrlFactory;
module.exports = exports['default'];